==> yasm-0.2.0.tar.gz: yasm-0.2.0/nasm-bison.h <==
/* A Bison parser, made from /home/pete/project/yasm-clean/yasm/modules/parsers/nasm/nasm-bison.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     INTNUM = 258,
     FLTNUM = 259,
     DIRECTIVE_NAME = 260,
     STRING = 261,
     FILENAME = 262,
     BYTE = 263,
     WORD = 264,
     DWORD = 265,
     QWORD = 266,
     TWORD = 267,
     DQWORD = 268,
     DECLARE_DATA = 269,
     RESERVE_SPACE = 270,
     INCBIN = 271,
     EQU = 272,
     TIMES = 273,
     SEG = 274,
     WRT = 275,
     NOSPLIT = 276,
     INSN = 277,
     PREFIX = 278,
     REG = 279,
     SEGREG = 280,
     TARGETMOD = 281,
     LEFT_OP = 282,
     RIGHT_OP = 283,
     SIGNDIV = 284,
     SIGNMOD = 285,
     START_SECTION_ID = 286,
     ID = 287,
     LOCAL_ID = 288,
     SPECIAL_ID = 289,
     LINE = 290,
     UNARYOP = 291
   };
#endif
#define INTNUM 258
#define FLTNUM 259
#define DIRECTIVE_NAME 260
#define STRING 261
#define FILENAME 262
#define BYTE 263
#define WORD 264
#define DWORD 265
#define QWORD 266
#define TWORD 267
#define DQWORD 268
#define DECLARE_DATA 269
#define RESERVE_SPACE 270
#define INCBIN 271
#define EQU 272
#define TIMES 273
#define SEG 274
#define WRT 275
#define NOSPLIT 276
#define INSN 277
#define PREFIX 278
#define REG 279
#define SEGREG 280
#define TARGETMOD 281
#define LEFT_OP 282
#define RIGHT_OP 283
#define SIGNDIV 284
#define SIGNMOD 285
#define START_SECTION_ID 286
#define ID 287
#define LOCAL_ID 288
#define SPECIAL_ID 289
#define LINE 290
#define UNARYOP 291




#ifndef YYSTYPE
#line 57 "nasm-bison.y"
typedef union {
    unsigned int int_info;
    char *str_val;
    yasm_intnum *intn;
    yasm_floatnum *flt;
    yasm_symrec *sym;
    unsigned long arch_data[4];
    yasm_effaddr *ea;
    yasm_expr *exp;
    yasm_datavalhead datahead;
    yasm_dataval *data;
    yasm_bytecode *bc;
    yasm_valparamhead dir_valparams;
    yasm_valparam *dir_valparam;
    struct {
	yasm_insn_operandhead operands;
	int num_operands;
    } insn_operands;
    yasm_insn_operand *insn_operand;
} yystype;
/* Line 1281 of /usr/local/share/bison/yacc.c.  */
#line 133 "nasm-bison.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_Y_TAB_H */

==> yasm-0.5.0.tar.gz: yasm-0.5.0/nasm-bison.h <==
/* A Bison parser, made from /home/pete/project/yasm/tags/yasm-0.5.0/modules/parsers/nasm/nasm-bison.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     INTNUM = 258,
     FLTNUM = 259,
     DIRECTIVE_NAME = 260,
     FILENAME = 261,
     STRING = 262,
     ONECHARSTR = 263,
     SIZE_OVERRIDE = 264,
     DECLARE_DATA = 265,
     RESERVE_SPACE = 266,
     INCBIN = 267,
     EQU = 268,
     TIMES = 269,
     SEG = 270,
     WRT = 271,
     NOSPLIT = 272,
     INSN = 273,
     PREFIX = 274,
     REG = 275,
     SEGREG = 276,
     TARGETMOD = 277,
     LEFT_OP = 278,
     RIGHT_OP = 279,
     SIGNDIV = 280,
     SIGNMOD = 281,
     START_SECTION_ID = 282,
     ID = 283,
     LOCAL_ID = 284,
     SPECIAL_ID = 285,
     LINE = 286,
     UNARYOP = 287
   };
#endif
#define INTNUM 258
#define FLTNUM 259
#define DIRECTIVE_NAME 260
#define FILENAME 261
#define STRING 262
#define ONECHARSTR 263
#define SIZE_OVERRIDE 264
#define DECLARE_DATA 265
#define RESERVE_SPACE 266
#define INCBIN 267
#define EQU 268
#define TIMES 269
#define SEG 270
#define WRT 271
#define NOSPLIT 272
#define INSN 273
#define PREFIX 274
#define REG 275
#define SEGREG 276
#define TARGETMOD 277
#define LEFT_OP 278
#define RIGHT_OP 279
#define SIGNDIV 280
#define SIGNMOD 281
#define START_SECTION_ID 282
#define ID 283
#define LOCAL_ID 284
#define SPECIAL_ID 285
#define LINE 286
#define UNARYOP 287




#ifndef YYSTYPE
#line 62 "nasm-bison.y"
typedef union {
    unsigned int int_info;
    char *str_val;
    yasm_intnum *intn;
    yasm_floatnum *flt;
    yasm_symrec *sym;
    unsigned long arch_data[4];
    yasm_effaddr *ea;
    yasm_expr *exp;
    yasm_datavalhead datahead;
    yasm_dataval *data;
    yasm_bytecode *bc;
    yasm_valparamhead dir_valparams;
    yasm_valparam *dir_valparam;
    struct {
	yasm_insn_operands operands;
	int num_operands;
    } insn_operands;
    yasm_insn_operand *insn_operand;
    struct {
	char *name;
	int local;
    } label;
    struct {
	char *contents;
	size_t len;
    } str;
} yystype;
/* Line 1281 of /usr/local/share/bison/yacc.c.  */
#line 133 "nasm-bison.h"
# define YYSTYPE yystype
#endif




#endif /* not BISON_Y_TAB_H */
